@@ -21,6 +21,11 @@ if [ ! -d "$bundle_name.app/Contents/Resources" ]; then
   mkdir -p "$bundle_name.app/Contents/Resources"
 fi
 
+if [ ! -d "$bundle_name.app/Contents/Frameworks" ]; then
+  mkdir -p "$bundle_name.app/Contents/Frameworks"
+fi
+
+cp -rf /Library/Frameworks/SDL.framework "$bundle_name.app/Contents/Frameworks/"
 cp -f "$binary_name" "$bundle_name.app/Contents/MacOS"
 
 if [ ! -f "$bundle_name.app/Contents/PkgInfo" ]; then
